# IBM watsonx.ai LangChain interface

This is a Python library to add a LangChain interface to IBM watsonx.ai. This is not an IBM project and is not supported by IBM.

To install,

```shell
pip install wxai-langchain
```

To use, see the examples folder. This LangChain interface is not compatible with IBM's GenAI GenerateParams schema object.
Always use a JSON for the model's parameters as shown in the examples.